@@ -1,7 +1,7 @@
 #!/bin/sh
 echo 'name: convertible
-version: 1.0.9.1
-id: convertible-1.0.9.1-7621ca24e5a818e3c272c93b14228d46
+version: 1.0.10.0
+id: convertible-1.0.10.0-ac601b0c88786ad4f8f48968eb9cd8ee
 
 license: LGPL
 copyright: Copyright (c) 2009-2010 John Goerzen
@@ -36,27 +36,29 @@ exposed: True
 exposed-modules: Data.Convertible Data.Convertible.Base
                  Data.Convertible.Utils Data.Convertible.Instances
                  Data.Convertible.Instances.C Data.Convertible.Instances.Map
-                 Data.Convertible.Instances.Num Data.Convertible.Instances.Time
+                 Data.Convertible.Instances.Num Data.Convertible.Instances.Text
+                 Data.Convertible.Instances.Time
 hidden-modules:
-import-dirs: /usr/local/lib/ghc/convertible-1.0.9.1
-library-dirs: /usr/local/lib/ghc/convertible-1.0.9.1
-hs-libraries: HSconvertible-1.0.9.1
+import-dirs: /usr/local/lib/ghc/convertible-1.0.10.0
+library-dirs: /usr/local/lib/ghc/convertible-1.0.10.0
+hs-libraries: HSconvertible-1.0.10.0
 extra-libraries:
 extra-ghci-libraries:
 include-dirs:
 includes:
-depends: base-4.2.0.2-af431bb15643ef1ce2792a51c33968b3
-         bytestring-0.9.1.7-352f069cca85cb3f9e4c06bb76ec4cec
-         containers-0.3.0.0-7be04792060ce1514c52e2cb13a5c18a
-         mtl-1.1.0.2-9e35d291e0ab20c6aa18823de23bc2de
-         old-locale-1.0.0.2-0c1a4b40f2d3b9f6b725f54c00fe0923
-         old-time-1.0.0.5-56dd504e1de073228be3dcc82225ab48
-         time-1.1.4-668ce7f110e803952c4ceda6e172096c
+depends: base-4.3.1.0-e1ba2d2213b66179f3e0c901a27d3a96
+         bytestring-0.9.1.10-2da7b519f76934c0e733bf92c23382ec
+         containers-0.4.0.0-8781485edb2ac0db733a9f9c72e27945
+         mtl-2.0.1.0-91f62d81c946aa60137dcc008e554a3a
+         old-locale-1.0.0.2-cc522edd16b73a70b897598c5f5d20c7
+         old-time-1.0.0.6-dfdb9c34ec39bc9a2a57345b38e135d4
+         text-0.11.0.6-8c4af07195c37bf4d73ffb41fc92ea29
+         time-1.2.0.3-4f1bed38bdf37d398ba8f4311cbdac4a
 hugs-options:
 cc-options:
 ld-options:
 framework-dirs:
 frameworks:
-haddock-interfaces: /usr/local/share/doc/hs-convertible-1.0.9.1/html/convertible.haddock
-haddock-html: /usr/local/share/doc/hs-convertible-1.0.9.1/html
+haddock-interfaces: /usr/local/share/doc/hs-convertible-1.0.10.0/html/convertible.haddock
+haddock-html: /usr/local/share/doc/hs-convertible-1.0.10.0/html
 ' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
